package com.sun.corba.se.spi.orb;

import com.sun.corba.se.spi.copyobject.CopierManager;
import com.sun.corba.se.spi.orbutil.threadpool.ThreadPoolManager;
import com.sun.corba.se.impl.transport.ByteBufferPoolImpl;
import com.sun.corba.se.spi.logging.LogWrapperBase;
import com.sun.corba.se.spi.logging.LogWrapperFactory;
import java.util.logging.Logger;
import com.sun.corba.se.spi.ior.ObjectKeyFactory;
import com.sun.corba.se.spi.ior.IdentifiableFactoryFinder;
import com.sun.corba.se.spi.ior.TaggedComponentFactoryFinder;
import com.sun.corba.se.spi.protocol.CorbaServerRequestDispatcher;
import com.sun.corba.se.spi.resolver.LocalResolver;
import com.sun.corba.se.spi.resolver.Resolver;
import com.sun.corba.se.spi.transport.CorbaContactInfoListFactory;
import com.sun.corba.se.spi.protocol.ClientDelegateFactory;
import com.sun.corba.se.spi.protocol.RequestDispatcherRegistry;
import com.sun.corba.se.spi.servicecontext.ServiceContextRegistry;
import com.sun.corba.se.spi.protocol.PIHandler;
import com.sun.corba.se.impl.oa.poa.BadServerIdHandler;
import com.sun.corba.se.spi.ior.ObjectKey;
import com.sun.corba.se.spi.ior.IOR;
import java.util.Properties;
import com.sun.corba.se.spi.monitoring.MonitoringFactories;
import java.util.HashMap;
import java.util.concurrent.ConcurrentHashMap;
import sun.awt.AppContext;
import com.sun.corba.se.impl.presentation.rmi.PresentationManagerImpl;
import sun.corba.SharedSecrets;
import com.sun.corba.se.spi.presentation.rmi.PresentationDefaults;
import java.security.AccessController;
import java.security.PrivilegedAction;
import com.sun.corba.se.spi.presentation.rmi.PresentationManager;
import com.sun.corba.se.spi.legacy.connection.LegacyServerSocketManager;
import com.sun.corba.se.spi.transport.CorbaTransportManager;
import com.sun.corba.se.spi.oa.OAInvocationInfo;
import com.sun.corba.se.spi.monitoring.MonitoringManager;
import com.sun.corba.se.pept.transport.ByteBufferPool;
import com.sun.corba.se.impl.corba.TypeCodeImpl;
import java.util.Map;
import com.sun.corba.se.impl.logging.OMGSystemException;
import com.sun.corba.se.impl.logging.ORBUtilSystemException;
import com.sun.corba.se.impl.corba.TypeCodeFactory;
import com.sun.corba.se.pept.broker.Broker;

public abstract class ORB extends com.sun.corba.se.org.omg.CORBA.ORB implements Broker, TypeCodeFactory
{
    public static boolean ORBInitDebug;
    public boolean transportDebugFlag;
    public boolean subcontractDebugFlag;
    public boolean poaDebugFlag;
    public boolean poaConcurrencyDebugFlag;
    public boolean poaFSMDebugFlag;
    public boolean orbdDebugFlag;
    public boolean namingDebugFlag;
    public boolean serviceContextDebugFlag;
    public boolean transientObjectManagerDebugFlag;
    public boolean giopVersionDebugFlag;
    public boolean shutdownDebugFlag;
    public boolean giopDebugFlag;
    public boolean invocationTimingDebugFlag;
    public boolean orbInitDebugFlag;
    protected static ORBUtilSystemException staticWrapper;
    protected ORBUtilSystemException wrapper;
    protected OMGSystemException omgWrapper;
    private Map typeCodeMap;
    private TypeCodeImpl[] primitiveTypeCodeConstants;
    ByteBufferPool byteBufferPool;
    private Map wrapperMap;
    private static final Object pmLock;
    private static Map staticWrapperMap;
    protected MonitoringManager monitoringManager;
    
    public abstract boolean isLocalHost(String p0);
    
    public abstract boolean isLocalServerId(int p0, int p1);
    
    public abstract OAInvocationInfo peekInvocationInfo();
    
    public abstract void pushInvocationInfo(OAInvocationInfo p0);
    
    public abstract OAInvocationInfo popInvocationInfo();
    
    public abstract CorbaTransportManager getCorbaTransportManager();
    
    public abstract LegacyServerSocketManager getLegacyServerSocketManager();
    
    private static PresentationManager setupPresentationManager() {
        ORB.staticWrapper = ORBUtilSystemException.get("rpc.presentation");
        int booleanValue = (boolean)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                return Boolean.valueOf(Boolean.getBoolean("com.sun.CORBA.ORBUseDynamicStub"));
            }
        });
        PresentationManager.StubFactoryFactory stubFactoryFactory = (PresentationManager.StubFactoryFactory)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                PresentationManager.StubFactoryFactory proxyStubFactoryFactory = PresentationDefaults.getProxyStubFactoryFactory();
                String property = System.getProperty("com.sun.CORBA.ORBDynamicStubFactoryFactoryClass", "com.sun.corba.se.impl.presentation.rmi.bcel.StubFactoryFactoryBCELImpl");
                try {
                    proxyStubFactoryFactory = (PresentationManager.StubFactoryFactory)SharedSecrets.getJavaCorbaAccess().loadClass(property).newInstance();
                }
                catch (Exception ex) {
                    ORB.staticWrapper.errorInSettingDynamicStubFactoryFactory(ex, property);
                }
                return proxyStubFactoryFactory;
            }
        });
        PresentationManagerImpl presentationManagerImpl = new PresentationManagerImpl((boolean)booleanValue);
        presentationManagerImpl.setStubFactoryFactory(false, PresentationDefaults.getStaticStubFactoryFactory());
        presentationManagerImpl.setStubFactoryFactory(true, stubFactoryFactory);
        return presentationManagerImpl;
    }
    
    public void destroy() {
        this.wrapper = null;
        this.omgWrapper = null;
        this.typeCodeMap = null;
        this.primitiveTypeCodeConstants = null;
        this.byteBufferPool = null;
    }
    
    public static PresentationManager getPresentationManager() {
        if (System.getSecurityManager() != null && AppContext.getAppContexts().size() > 0) {
            AppContext appContext = AppContext.getAppContext();
            if (appContext != null) {
                synchronized (ORB.pmLock) {
                    PresentationManager setupPresentationManager = (PresentationManager)appContext.get(PresentationManager.class);
                    if (setupPresentationManager == null) {
                        setupPresentationManager = setupPresentationManager();
                        appContext.put(PresentationManager.class, setupPresentationManager);
                    }
                    return setupPresentationManager;
                }
            }
        }
        return ORB.Holder.defaultPresentationManager;
    }
    
    public static PresentationManager.StubFactoryFactory getStubFactoryFactory() {
        PresentationManager presentationManager = getPresentationManager();
        return presentationManager.getStubFactoryFactory(presentationManager.useDynamicStubs());
    }
    
    protected ORB() {
        this.transportDebugFlag = false;
        this.subcontractDebugFlag = false;
        this.poaDebugFlag = false;
        this.poaConcurrencyDebugFlag = false;
        this.poaFSMDebugFlag = false;
        this.orbdDebugFlag = false;
        this.namingDebugFlag = false;
        this.serviceContextDebugFlag = false;
        this.transientObjectManagerDebugFlag = false;
        this.giopVersionDebugFlag = false;
        this.shutdownDebugFlag = false;
        this.giopDebugFlag = false;
        this.invocationTimingDebugFlag = false;
        this.orbInitDebugFlag = false;
        this.wrapperMap = new ConcurrentHashMap();
        this.wrapper = ORBUtilSystemException.get(this, "rpc.presentation");
        this.omgWrapper = OMGSystemException.get(this, "rpc.presentation");
        this.typeCodeMap = new HashMap();
        this.primitiveTypeCodeConstants = new TypeCodeImpl[] { new TypeCodeImpl(this, 0), new TypeCodeImpl(this, 1), new TypeCodeImpl(this, 2), new TypeCodeImpl(this, 3), new TypeCodeImpl(this, 4), new TypeCodeImpl(this, 5), new TypeCodeImpl(this, 6), new TypeCodeImpl(this, 7), new TypeCodeImpl(this, 8), new TypeCodeImpl(this, 9), new TypeCodeImpl(this, 10), new TypeCodeImpl(this, 11), new TypeCodeImpl(this, 12), new TypeCodeImpl(this, 13), new TypeCodeImpl(this, 14), null, null, null, new TypeCodeImpl(this, 18), null, null, null, null, new TypeCodeImpl(this, 23), new TypeCodeImpl(this, 24), new TypeCodeImpl(this, 25), new TypeCodeImpl(this, 26), new TypeCodeImpl(this, 27), new TypeCodeImpl(this, 28), new TypeCodeImpl(this, 29), new TypeCodeImpl(this, 30), new TypeCodeImpl(this, 31), new TypeCodeImpl(this, 32) };
        this.monitoringManager = MonitoringFactories.getMonitoringManagerFactory().createMonitoringManager("orb", "ORB Management and Monitoring Root");
    }
    
    public TypeCodeImpl get_primitive_tc(int value) {
        synchronized (this) {
            this.checkShutdownState();
        }
        try {
            return this.primitiveTypeCodeConstants[value];
        }
        catch (Throwable t) {
            throw this.wrapper.invalidTypecodeKind(t, new Integer(value));
        }
    }
    
    public synchronized void setTypeCode(String s, TypeCodeImpl typeCodeImpl) {
        this.checkShutdownState();
        this.typeCodeMap.put(s, typeCodeImpl);
    }
    
    public synchronized TypeCodeImpl getTypeCode(String s) {
        this.checkShutdownState();
        return (TypeCodeImpl)this.typeCodeMap.get(s);
    }
    
    public MonitoringManager getMonitoringManager() {
        synchronized (this) {
            this.checkShutdownState();
        }
        return this.monitoringManager;
    }
    
    public abstract void set_parameters(Properties p0);
    
    public abstract ORBVersion getORBVersion();
    
    public abstract void setORBVersion(ORBVersion p0);
    
    public abstract IOR getFVDCodeBaseIOR();
    
    public abstract void handleBadServerId(ObjectKey p0);
    
    public abstract void setBadServerIdHandler(BadServerIdHandler p0);
    
    public abstract void initBadServerIdHandler();
    
    public abstract void notifyORB();
    
    public abstract PIHandler getPIHandler();
    
    public abstract void checkShutdownState();
    
    public abstract boolean isDuringDispatch();
    
    public abstract void startingDispatch();
    
    public abstract void finishedDispatch();
    
    public abstract int getTransientServerId();
    
    public abstract ServiceContextRegistry getServiceContextRegistry();
    
    public abstract RequestDispatcherRegistry getRequestDispatcherRegistry();
    
    public abstract ORBData getORBData();
    
    public abstract void setClientDelegateFactory(ClientDelegateFactory p0);
    
    public abstract ClientDelegateFactory getClientDelegateFactory();
    
    public abstract void setCorbaContactInfoListFactory(CorbaContactInfoListFactory p0);
    
    public abstract CorbaContactInfoListFactory getCorbaContactInfoListFactory();
    
    public abstract void setResolver(Resolver p0);
    
    public abstract Resolver getResolver();
    
    public abstract void setLocalResolver(LocalResolver p0);
    
    public abstract LocalResolver getLocalResolver();
    
    public abstract void setURLOperation(Operation p0);
    
    public abstract Operation getURLOperation();
    
    public abstract void setINSDelegate(CorbaServerRequestDispatcher p0);
    
    public abstract TaggedComponentFactoryFinder getTaggedComponentFactoryFinder();
    
    public abstract IdentifiableFactoryFinder getTaggedProfileFactoryFinder();
    
    public abstract IdentifiableFactoryFinder getTaggedProfileTemplateFactoryFinder();
    
    public abstract ObjectKeyFactory getObjectKeyFactory();
    
    public abstract void setObjectKeyFactory(ObjectKeyFactory p0);
    
    public Logger getLogger(String s) {
        synchronized (this) {
            this.checkShutdownState();
        }
        ORBData orbData = this.getORBData();
        String orbId;
        if (orbData == null) {
            orbId = "_INITIALIZING_";
        }
        else {
            orbId = orbData.getORBId();
            if (orbId.equals("")) {
                orbId = "_DEFAULT_";
            }
        }
        return getCORBALogger(orbId, s);
    }
    
    public static Logger staticGetLogger(String s) {
        return getCORBALogger("_CORBA_", s);
    }
    
    private static Logger getCORBALogger(String str, String str2) {
        return Logger.getLogger("javax.enterprise.resource.corba." + str + "." + str2, "com.sun.corba.se.impl.logging.LogStrings");
    }
    
    public LogWrapperBase getLogWrapper(String s, String s2, LogWrapperFactory logWrapperFactory) {
        StringPair stringPair = new StringPair(s, s2);
        LogWrapperBase create = (LogWrapperBase)this.wrapperMap.get(stringPair);
        if (create == null) {
            create = logWrapperFactory.create(this.getLogger(s));
            this.wrapperMap.put(stringPair, create);
            return create;
        }
        return create;
    }
    
    public static LogWrapperBase staticGetLogWrapper(String s, String s2, LogWrapperFactory logWrapperFactory) {
        StringPair stringPair = new StringPair(s, s2);
        LogWrapperBase create = (LogWrapperBase)ORB.staticWrapperMap.get(stringPair);
        if (create == null) {
            create = logWrapperFactory.create(staticGetLogger(s));
            ORB.staticWrapperMap.put(stringPair, create);
            return create;
        }
        return create;
    }
    
    public ByteBufferPool getByteBufferPool() {
        synchronized (this) {
            this.checkShutdownState();
        }
        if (this.byteBufferPool == null) {
            this.byteBufferPool = new ByteBufferPoolImpl(this);
        }
        return this.byteBufferPool;
    }
    
    public abstract void setThreadPoolManager(ThreadPoolManager p0);
    
    public abstract ThreadPoolManager getThreadPoolManager();
    
    public abstract CopierManager getCopierManager();
    
    public abstract void validateIORClass(String p0);
    
    static PresentationManager access$000() {
        return setupPresentationManager();
    }
    
    static {
        ORB.ORBInitDebug = false;
        pmLock = new Object();
        ORB.staticWrapperMap = new ConcurrentHashMap();
    }
    
    static class Holder
    {
        static final PresentationManager defaultPresentationManager;
        
        static {
            defaultPresentationManager = ORB.access$000();
        }
    }
}
